==> deepin-boot-maker_5.6.5+dfsg.orig.tar.gz: deepin-boot-maker_5.6.5+dfsg/src/translations/deepin-boot-maker_th.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="th">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="12"/>
        <source>Disk Format Error: Please reformat it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="15"/>
        <source>Insufficient disk Space: Ensure that the disk has enough free space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="18"/>
        <source>Disk Mount Error: Insert the disk again or reboot to retry</source>
        <translation>ข้อผิดพลาดของการเมานต์ดิสก์: ใส่ดิสก์อีกครั้งหรือรีบูตเพื่อลองอีกครั้ง</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="21"/>
        <source>Image Decompression Error: Verify md5 checksum of the image to ensure its integrity</source>
        <translation>ข้อผิดพลาดการบีบอัดรูปภาพ: ตรวจสอบแฮท md5 ของภาพเพื่อให้แน่ใจว่าสมบูรณ์</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="24"/>
        <source>Internal Error</source>
        <translation>ข้อผิดพลาดภายใน</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="79"/>
        <source>Boot Maker is a simple tool to write system image files into USB flash drives and other media.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="81"/>
        <source>Boot Maker</source>
        <translation>Boot Maker</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="125"/>
        <source>Drag an ISO image file here</source>
        <translation>ลากไฟล์อิมเมจ ISO ใส่ที่นี่</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="144"/>
        <source>OR</source>
        <translation>หรือ</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="89"/>
        <location filename="../app/view/isoselectview.cpp" line="163"/>
        <source>Select an ISO image file</source>
        <translation>เลือกไฟล์อิมเมจ ISO</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="214"/>
        <source>Next</source>
        <translation>ถัดไป</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="300"/>
        <source>Reselect an ISO image file</source>
        <translation>เลือกไฟล์อิมเมจ ISO อีกครั้ง</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="237"/>
        <source>Illegal ISO image file</source>
        <translation>ไฟล์อิมเมจ ISO ที่ผิดกฎหมาย</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="441"/>
        <source>Detecting ISO file, please wait...</source>
        <translation>กำลังตรวจหาไฟล์ ISO โปรดรอ...</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="62"/>
        <source>Burning</source>
        <translation>Burning</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="78"/>
        <source>Burning, please wait...</source>
        <translation>Burning, โปรดรอ...</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="90"/>
        <source>Do not remove the disk or shut down the computer during the process</source>
        <translation>อย่าดิสก์เอาหรือปิดเครื่องคอมพิวเตอร์ในระหว่างกระบวนการ</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="112"/>
        <source>Cancel</source>
        <translation>ยกเลิก</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="40"/>
        <source>Removable Disk</source>
        <translation>ดิสก์แบบถอดได้</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="221"/>
        <location filename="../libdbm/util/utils.cpp" line="365"/>
        <source>Removable disk</source>
        <translation>ดิสก์แบบถอดได้</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="118"/>
        <source>Boot Maker</source>
        <translation>Boot Maker</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="149"/>
        <source>Reboot now</source>
        <translation>รีบูทเดี๋ยวนี้</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="132"/>
        <source>Done</source>
        <translation>เสร็จสิ้น</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="66"/>
        <source>Successful</source>
        <translation>สำเร็จ</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="229"/>
        <source>The error log will be uploaded automatically with the feedback. We cannot improve without your feedback</source>
        <translation>บันทึกข้อผิดพลาดจะถูกอัปโหลดโดยอัตโนมัติพร้อมกับข้อเสนอแนะ เราไม่สามารถปรับปรุงได้หากไม่มีข้อเสนอแนะของคุณ</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="230"/>
        <source>Submit Feedback</source>
        <translation>ส่งข้อเสนอแนะ</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="253"/>
        <source>After-Sale Services</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="269"/>
        <source>Close</source>
        <translation>ปิด</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="277"/>
        <source>Sorry, process failed</source>
        <translation>ขออภัยกระบวนการล้มเหลว</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="278"/>
        <source>Process failed</source>
        <translation>กระบวนการล้มเหลว</translation>
    </message>
</context>
<context>
    <name>UnmountUsbView</name>
    <message>
        <location filename="../app/view/unmountusbview.cpp" line="13"/>
        <source>Verifying data and safely removing the media, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="87"/>
        <source>Select a partition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="114"/>
        <source>Format the partition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="162"/>
        <source>Start</source>
        <translation>เริ่ม</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="166"/>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="222"/>
        <source>Formatting will erase all data on the partition, but can increase the success rate, please confirm before proceeding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="318"/>
        <source>Formatting the partition will overwrite all data, please have a backup before proceeding.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="335"/>
        <source>Disk Format Error: Please format the partition with FAT32</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="147"/>
        <source>No disk available</source>
        <translation>ไม่มีดิสก์</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="316"/>
        <source>Format Partition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="319"/>
        <source>Cancel</source>
        <translation>ยกเลิก</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="320"/>
        <source>OK</source>
        <translation>ตกลง</translation>
    </message>
</context>
</TS>

==> deepin-boot-maker_5.6.12+dfsg.orig.tar.gz: deepin-boot-maker_5.6.12+dfsg/src/translations/deepin-boot-maker_th.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="th">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="16"/>
        <source>Disk Format Error: Please reformat it or disable &quot;Auto scan USB storage devices&quot; in Security Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="19"/>
        <source>Disk Format Error: Please reformat it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="24"/>
        <source>Insufficient disk Space: Ensure that the disk has enough free space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="27"/>
        <source>Disk Mount Error: Insert the disk again or reboot to retry</source>
        <translation>ข้อผิดพลาดของการเมานต์ดิสก์: ใส่ดิสก์อีกครั้งหรือรีบูตเพื่อลองอีกครั้ง</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="30"/>
        <source>Image Decompression Error: Verify md5 checksum of the image to ensure its integrity</source>
        <translation>ข้อผิดพลาดการบีบอัดรูปภาพ: ตรวจสอบแฮท md5 ของภาพเพื่อให้แน่ใจว่าสมบูรณ์</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="33"/>
        <source>Internal Error</source>
        <translation>ข้อผิดพลาดภายใน</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="79"/>
        <source>Boot Maker is a simple tool to write system image files into USB flash drives and other media.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="81"/>
        <source>Boot Maker</source>
        <translation>Boot Maker</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="126"/>
        <source>Drag an ISO image file here</source>
        <translation>ลากไฟล์อิมเมจ ISO ใส่ที่นี่</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="145"/>
        <source>OR</source>
        <translation>หรือ</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="89"/>
        <location filename="../app/view/isoselectview.cpp" line="163"/>
        <source>Select an ISO image file</source>
        <translation>เลือกไฟล์อิมเมจ ISO</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="211"/>
        <source>Next</source>
        <translation>ถัดไป</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="297"/>
        <source>Reselect an ISO image file</source>
        <translation>เลือกไฟล์อิมเมจ ISO อีกครั้ง</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="234"/>
        <source>Illegal ISO image file</source>
        <translation>ไฟล์อิมเมจ ISO ที่ผิดกฎหมาย</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="438"/>
        <source>Detecting ISO file, please wait...</source>
        <translation>กำลังตรวจหาไฟล์ ISO โปรดรอ...</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="62"/>
        <source>Burning</source>
        <translation>Burning</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="78"/>
        <source>Burning, please wait...</source>
        <translation>Burning, โปรดรอ...</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="90"/>
        <source>Do not remove the disk or shut down the computer during the process</source>
        <translation>อย่าดิสก์เอาหรือปิดเครื่องคอมพิวเตอร์ในระหว่างกระบวนการ</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="112"/>
        <source>Cancel</source>
        <translation>ยกเลิก</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="40"/>
        <source>Removable Disk</source>
        <translation>ดิสก์แบบถอดได้</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="223"/>
        <location filename="../libdbm/util/utils.cpp" line="369"/>
        <source>Removable disk</source>
        <translation>ดิสก์แบบถอดได้</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="118"/>
        <source>Boot Maker</source>
        <translation>Boot Maker</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="137"/>
        <source>Reboot now</source>
        <translation>รีบูทเดี๋ยวนี้</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="120"/>
        <source>Done</source>
        <translation>เสร็จสิ้น</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="68"/>
        <source>Successful</source>
        <translation>สำเร็จ</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="217"/>
        <source>The error log will be uploaded automatically with the feedback. We cannot improve without your feedback</source>
        <translation>บันทึกข้อผิดพลาดจะถูกอัปโหลดโดยอัตโนมัติพร้อมกับข้อเสนอแนะ เราไม่สามารถปรับปรุงได้หากไม่มีข้อเสนอแนะของคุณ</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="218"/>
        <source>Submit Feedback</source>
        <translation>ส่งข้อเสนอแนะ</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="241"/>
        <source>After-Sale Services</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="254"/>
        <source>Close</source>
        <translation>ปิด</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="262"/>
        <source>Sorry, process failed</source>
        <translation>ขออภัยกระบวนการล้มเหลว</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="263"/>
        <source>Process failed</source>
        <translation>กระบวนการล้มเหลว</translation>
    </message>
</context>
<context>
    <name>UnmountUsbView</name>
    <message>
        <location filename="../app/view/unmountusbview.cpp" line="13"/>
        <source>Verifying data and safely removing the media, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="95"/>
        <source>Select a partition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="122"/>
        <source>Format the partition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="171"/>
        <source>Start</source>
        <translation>เริ่ม</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="175"/>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="231"/>
        <source>Formatting will erase all data on the partition, but can increase the success rate, please confirm before proceeding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="368"/>
        <source>Formatting the partition will overwrite all data, please have a backup before proceeding.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="402"/>
        <source>Disk Format Error: Please format the partition with FAT32</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="156"/>
        <source>No disk available</source>
        <translation>ไม่มีดิสก์</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="365"/>
        <source>Format Partition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="372"/>
        <source>Cancel</source>
        <translation>ยกเลิก</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="374"/>
        <source>OK</source>
        <translation>ตกลง</translation>
    </message>
</context>
</TS>
